@@ -1,4 +1,4 @@
-{-# LANGUAGE OverloadedStrings, CPP #-}
+{-# LANGUAGE OverloadedStrings #-}
 module Text.HTML.DOM
     ( eventConduit
     , sinkDoc
@@ -10,9 +10,7 @@ module Text.HTML.DOM
 import Control.Monad.Trans.Resource
 import Prelude hiding (readFile)
 import qualified Data.ByteString as S
-#if MIN_VERSION_tagstream_conduit(0,5,0)
 import qualified Text.HTML.TagStream.Text as TS
-#endif
 import qualified Text.HTML.TagStream as TS
 import qualified Data.XML.Types as XT
 import Data.Conduit
@@ -41,7 +39,7 @@ eventConduit =
   where
     go stack = do
         mx <- await
-        case fmap entities mx of
+        case mx of
             Nothing -> closeStack stack
 
             -- Ignore processing instructions (or pseudo-instructions)
@@ -75,24 +73,6 @@ eventConduit =
     toName l = XT.Name l Nothing Nothing
     closeStack = mapM_ (yield . XT.EventEndElement)
 
-    entities :: TS.Token' Text -> TS.Token' Text
-    entities (TS.TagOpen x pairs b) = TS.TagOpen x (map (second entities') pairs) b
-    entities (TS.Text x) = TS.Text $ entities' x
-    entities ts = ts
-
-    entities' :: Text -> Text
-    entities' t =
-        case T.break (== '&') t of
-            (_, "") -> t
-            (before, t') ->
-                case T.break (== ';') $ T.drop 1 t' of
-                    (_, "") -> t
-                    (entity, rest') ->
-                        let rest = T.drop 1 rest'
-                         in case decodeHtmlEntities entity of
-                                XT.ContentText entity' -> T.concat [before, entity', entities' rest]
-                                XT.ContentEntity _ -> T.concat [before, "&", entity, entities' rest']
-
     isVoid = flip Set.member $ Set.fromList
         [ "area"
         , "base"
